@@ -1,40 +1,25 @@
-use crate::server::{
-    RpcManager,
-    RpcMethods,
-};
+use crate::server::{RpcManager, RpcMethods};
 use crate::StatesList;
 use async_trait::async_trait;
 use gveditor_core_api::messaging::Messages;
 use hyper_tungstenite::hyper::upgrade::Upgraded;
-use hyper_tungstenite::tungstenite::{
-    self,
-    Message,
-};
-use hyper_tungstenite::{
-    hyper,
-    HyperWebsocket,
-    WebSocketStream,
-};
+use hyper_tungstenite::tungstenite::{self, Message};
+use hyper_tungstenite::{hyper, HyperWebsocket, WebSocketStream};
 use jsonrpc_core::futures::StreamExt;
+use jsonrpc_core::futures_executor::block_on;
 use jsonrpc_core::futures_util::stream::SplitSink;
 use jsonrpc_core::futures_util::SinkExt;
 use jsonrpc_core::IoHandler;
 use jsonrpc_http_server::{
-    AccessControlAllowOrigin,
-    DomainsValidation,
-    RequestMiddleware,
-    RequestMiddlewareAction,
+    AccessControlAllowOrigin, DomainsValidation, RequestMiddleware, RequestMiddlewareAction,
     RestApi,
 };
 use std::collections::HashMap;
-use std::sync::{
-    Arc,
-    Mutex,
-};
+use std::sync::Arc;
 use std::thread;
 use tokio::runtime::Runtime;
 use tokio::sync::mpsc::Sender;
-use tokio::sync::Mutex as AsyncMutex;
+use tokio::sync::Mutex;
 
 use jsonrpc_core::serde_json;
 
@@ -89,9 +74,9 @@ impl WSMessages {
 }
 
 type SocketsRegistry = Arc<
-    AsyncMutex<
+    Mutex<
         Vec<(
-            Arc<AsyncMutex<SplitSink<WebSocketStream<Upgraded>, tungstenite::Message>>>,
+            Arc<Mutex<SplitSink<WebSocketStream<Upgraded>, tungstenite::Message>>>,
             u8,
         )>,
     >,
@@ -111,7 +96,8 @@ impl RequestMiddleware for WebSocketsManager {
         request: jsonrpc_http_server::hyper::Request<jsonrpc_http_server::hyper::Body>,
     ) -> RequestMiddlewareAction {
         // Authentificate the websockets connection
-        if !Self::auth_ws(&request, &self.states) {
+        // TODO: Don't use block_on
+        if !block_on(Self::auth_ws(&request, &self.states)) {
             return request.into();
         }
 
@@ -156,7 +142,10 @@ impl WebSocketsManager {
     ///
     /// * `request`           - The Hyper request
     /// * `states`            - A States list
-    pub fn auth_ws(request: &hyper::Request<hyper::Body>, states: &Arc<Mutex<StatesList>>) -> bool {
+    pub async fn auth_ws(
+        request: &hyper::Request<hyper::Body>,
+        states: &Arc<Mutex<StatesList>>,
+    ) -> bool {
         let url = request.uri();
         // Create a URL to so the parameters can be queried
         let url = url::Url::parse(&format!("ws://locahost{}", &url.to_string())).unwrap();
@@ -168,9 +157,9 @@ impl WebSocketsManager {
         if let (Some(token), Some(state_id)) = (token, state_id) {
             let state_id = state_id.parse::<u8>();
             if let Ok(state_id) = state_id {
-                if let Some(state) = states.lock().unwrap().get_state_by_id(state_id) {
+                if let Some(state) = states.lock().await.get_state_by_id(state_id) {
                     // If found, then make sure the token is valid
-                    state.lock().unwrap().has_token(token)
+                    state.lock().await.has_token(token)
                 } else {
                     false
                 }
@@ -186,7 +175,7 @@ impl WebSocketsManager {
     ///
     /// * `states`               - A States list
     /// * `core_sender`          - A sender to communicate to the Core
-    /// * `websocklet`           - The Websockets connection
+    /// * `websocket`           - The Websockets connection
     pub fn handle_ws(
         sockets: SocketsRegistry,
         core_sender: Sender<Messages>,
@@ -198,7 +187,7 @@ impl WebSocketsManager {
             runtime.block_on(async {
                 let websocket = websocket.await.unwrap();
                 let (sender, mut recv) = websocket.split();
-                let sender = Arc::new(AsyncMutex::new(sender));
+                let sender = Arc::new(Mutex::new(sender));
 
                 // Handle new incoming message in the ws connection
                 while let Some(Ok(message)) = recv.next().await {
@@ -234,7 +223,7 @@ impl HTTPHandler {
     pub fn new(json_rpc_http_cors: DomainsValidation<AccessControlAllowOrigin>, port: u16) -> Self {
         Self {
             json_rpc_http_cors,
-            sockets: Arc::new(AsyncMutex::new(Vec::new())),
+            sockets: Arc::new(Mutex::new(Vec::new())),
             port,
         }
     }
@@ -308,93 +297,83 @@ impl TransportHandler for HTTPHandler {
 #[cfg(test)]
 mod tests {
 
-    use std::sync::{
-        Arc,
-        Mutex,
-    };
+    use std::sync::Arc;
     use std::time::Duration;
 
-    use gveditor_core_api::extensions::manager::ExtensionsManager;
     use gveditor_core_api::state::TokenFlags;
-    use gveditor_core_api::State;
-    use hyper_tungstenite::tungstenite::{
-        connect,
-        Message,
-    };
+    use gveditor_core_api::{Mutex, State};
+    use hyper_tungstenite::tungstenite::Message;
+    use jsonrpc_core::futures_util::{SinkExt, StreamExt};
     use jsonrpc_core::serde_json;
-    use tokio::runtime::Runtime;
     use tokio::sync::mpsc::channel;
     use tokio::time::sleep;
     use url::Url;
 
-    use crate::handlers::http::AsyncMutex;
     use crate::handlers::Messages;
-    use crate::{
-        Configuration,
-        Core,
-        StatesList,
-    };
+    use crate::{Configuration, Server, StatesList};
 
     use super::HTTPHandler;
 
-    #[test]
-    fn json_rpc_works() {
-        let rt = Runtime::new().unwrap();
-        rt.block_on(async {
-            // RUN THE SERVER
+    #[tokio::test]
+    async fn json_rpc_works() {
+        // RUN THE SERVER
 
-            let (to_core, from_core) = channel::<Messages>(1);
-            let from_core = Arc::new(AsyncMutex::new(from_core));
+        let (to_core, from_core) = channel::<Messages>(1);
 
-            let states = {
-                let sample_state = State::new(1, ExtensionsManager::default());
+        let states = {
+            let sample_state = State::default();
 
-                let states = StatesList::new()
-                    .with_tokens(&[TokenFlags::All("test".to_string())])
-                    .with_state(sample_state);
+            let states = StatesList::new()
+                .with_tokens(&[TokenFlags::All("test".to_string())])
+                .with_state(sample_state);
 
-                Arc::new(Mutex::new(states))
-            };
+            Arc::new(Mutex::new(states))
+        };
 
-            let http_handler = HTTPHandler::builder().build().wrap();
+        let http_handler = HTTPHandler::builder().build().wrap();
 
-            let config = Configuration::new(http_handler, to_core, from_core);
+        let config = Configuration::new(http_handler, to_core, from_core);
 
-            let core = Core::new(config, states);
+        let core = Server::new(config, states);
 
-            core.run().await;
+        core.run().await;
 
-            sleep(Duration::from_secs(2)).await;
+        sleep(Duration::from_secs(2)).await;
 
-            // RUN A WEBSOCKETS CLIENT
+        // RUN A WEBSOCKETS CLIENT
 
-            let (mut socket, _) = connect(
-                Url::parse("ws://localhost:50010/websockets?token=test&state_id=1").unwrap(),
-            )
-            .expect("Can't connect");
+        let (socket, _) = tokio_tungstenite::connect_async(
+            Url::parse("ws://localhost:50010/websockets?token=test&state_id=1").unwrap(),
+        )
+        .await
+        .unwrap();
 
-            let listen_to_state_msg = Messages::ListenToState {
-                state_id: 1,
-                trigger: "client".to_string(),
-            };
+        let (mut writer, mut reader) = socket.split();
 
-            let listen_to_state_msg = serde_json::to_string(&listen_to_state_msg).unwrap();
+        let listen_to_state_msg = Messages::ListenToState {
+            state_id: 1,
+            trigger: "client".to_string(),
+        };
 
-            socket
-                .write_message(Message::Text(listen_to_state_msg))
+        let listen_to_state_msg = serde_json::to_string(&listen_to_state_msg).unwrap();
+
+        tokio::spawn(async move {
+            writer
+                .send(Message::Text(listen_to_state_msg))
+                .await
                 .unwrap();
-
-            let msg = socket.read_message().expect("Error reading message");
-
-            assert!(msg.is_text());
-
-            let msg = msg.into_text().unwrap();
-
-            let state_updated_msg = serde_json::from_str(&msg).unwrap();
-
-            assert!(matches!(state_updated_msg, Messages::StateUpdated { .. }))
-
-            // TO-DO TEST JSON RPC CLIENT
         });
+
+        let msg = reader.next().await.unwrap().unwrap();
+
+        assert!(msg.is_text());
+
+        let msg = msg.into_text().unwrap();
+
+        let state_updated_msg = serde_json::from_str(&msg).unwrap();
+
+        assert!(matches!(state_updated_msg, Messages::StateUpdated { .. }));
+
+        // TODO(marc2332) TEST JSON RPC CLIENT
     }
 }
