@@ -1,24 +1,15 @@
 use super::TransportHandler;
 use crate::server::gen_client::Client;
-use crate::server::{
-    RpcManager,
-    RpcMethods,
-};
+use crate::server::{RpcManager, RpcMethods};
 use crate::StatesList;
 use async_trait::async_trait;
 use gveditor_core_api::messaging::Messages;
+use gveditor_core_api::Mutex;
 use jsonrpc_core::IoHandler;
 use jsonrpc_core_client::transports::local;
-use std::sync::{
-    Arc,
-    Mutex,
-};
+use std::sync::Arc;
 use std::thread;
-use tokio::sync::mpsc::{
-    channel,
-    Receiver,
-    Sender,
-};
+use tokio::sync::mpsc::{channel, Receiver, Sender};
 
 /// This a local handler, meaning that you can use the JSON RPC Server directly
 pub struct LocalHandler {
@@ -59,9 +50,9 @@ impl TransportHandler for LocalHandler {
         let rv = self.receiver_to_local.clone();
 
         thread::spawn(move || {
-            let mut rv = rv.lock().unwrap();
             let runtime = tokio::runtime::Runtime::new().unwrap();
             runtime.block_on(async {
+                let mut rv = rv.lock().await;
                 loop {
                     if let Some(msg) = rv.recv().await {
                         core_sender.send(msg).await.unwrap();
@@ -79,54 +70,50 @@ impl TransportHandler for LocalHandler {
 #[cfg(test)]
 mod tests {
 
-    use std::sync::{
-        Arc,
-        Mutex,
-    };
+    use std::sync::Arc;
 
     use gveditor_core_api::extensions::manager::ExtensionsManager;
-    use gveditor_core_api::state::TokenFlags;
-    use gveditor_core_api::State;
+    use gveditor_core_api::state::{MemoryPersistor, TokenFlags};
+    use gveditor_core_api::{Mutex, State};
 
-    use tokio::runtime::Runtime;
     use tokio::sync::mpsc::channel;
 
     use crate::StatesList;
 
     use super::LocalHandler;
 
-    #[test]
-    fn json_rpc_works() {
-        let rt = Runtime::new().unwrap();
+    #[tokio::test]
+    async fn json_rpc_works() {
+        let (core_sender, _) = channel(1);
 
-        rt.block_on(async {
-            // Sample StatesList
-            let states = {
-                let sample_state = State::new(1, ExtensionsManager::default());
+        // Sample StatesList
+        let states = {
+            let sample_state = State::new(
+                1,
+                ExtensionsManager::new(core_sender.clone(), None),
+                Box::new(MemoryPersistor::new()),
+            );
 
-                // A StatesList with the previous state
-                let states = StatesList::new()
-                    .with_tokens(&[TokenFlags::All("test_token".to_string())])
-                    .with_state(sample_state);
-                Arc::new(Mutex::new(states))
-            };
+            // A StatesList with the previous state
+            let states = StatesList::new()
+                .with_tokens(&[TokenFlags::All("test_token".to_string())])
+                .with_state(sample_state);
+            Arc::new(Mutex::new(states))
+        };
 
-            let (core_sender, _) = channel(1);
+        // Crate the local handler
+        let (_, client, _) = LocalHandler::new(states, core_sender);
 
-            // Crate the local handler
-            let (_, client, _) = LocalHandler::new(states, core_sender);
+        // Use the client to call JSON RPC Methods
+        let req = client
+            .read_file_by_path(
+                "./readme.md".to_string(),
+                "local".to_string(),
+                1,
+                "test_token".to_string(),
+            )
+            .await;
 
-            // Use the client to call JSON RPC Methods
-            let req = client
-                .read_file_by_path(
-                    "./readme.md".to_string(),
-                    "local".to_string(),
-                    1,
-                    "test_token".to_string(),
-                )
-                .await;
-
-            assert!(req.is_ok());
-        });
+        assert!(req.is_ok());
     }
 }
