@@ -1,17 +1,19 @@
 use async_trait::async_trait;
 use gveditor_core_api::messaging::Messages;
-use std::sync::{
-    Arc,
-    Mutex,
-};
+use gveditor_core_api::Mutex;
+use std::sync::Arc;
 use tokio::sync::mpsc::Sender;
 
 use crate::StatesList;
 
+#[cfg(feature = "http_client")]
 mod http;
-mod local;
-
+#[cfg(feature = "http_client")]
 pub use http::HTTPHandler;
+
+#[cfg(feature = "local_client")]
+mod local;
+#[cfg(feature = "local_client")]
 pub use local::LocalHandler;
 
 #[async_trait]
